# Pymodoro timer

> Ever heard of a pymodoro timer? Probably yes.
> Should i explain what it is? Probably not.

Very early development version. I'm just learning python, please be patient with my skills at this time :)

## How to use
- Clone the repository
- run `./pymodoro.py`

```
optional arguments:
  -h, --help   show this help message and exit
  -w 25        Working minutes
  -b 5         Break minutes
  ```
  
  ### Todo:
  - fix publishing
  - Refactor
  - Add more notification sounds (different sounds for break and working states)
  - add some statistics
  - (?)